<?php
/**
 * File charged of Team Management in Thor:
 * Shows Members of project's groups and allows to organise them
 * Administrators can make developers or admins subgroups
 * and can manage the users: Accept them, refuse them, discharge them etc..
 *
 * $Horde: thor/team.php,v 1.31 2005/01/03 14:35:33 jan Exp $
 *
 * Copyright 2003-2005 Carlos Pedrinaci <cpedrinaci@yahoo.es>
 *
 * See the enclosed file COPYING for license information (GPL). If you did
 * not receive such a file, see also http://www.fsf.org/copyleft/gpl.html.
 */

@define('THOR_BASE', dirname(__FILE__));
require_once THOR_BASE . '/lib/base.php';
require_once 'Horde/Group.php';

/* If we aren't provided with a project, redirect to the projects list. */
$projectID = Util::getFormData('project_id');
if (empty($projectID)) {
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}

$project = &$thor->_projectsContainer->getProject($projectID);
if (is_a($project, 'PEAR_Error')) {
    $notification->push(_("Unable to retrieve the project from the DB."), 'horde.error');
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}

if (!$project->isUserOfKind(Auth::getAuth(), USERS_ADMINS)) {
    // It isn't an admin
    $notification->push(_("You can't access that page: You are not an administrator for that project."), 'horde.warning');
    header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
    exit;
}

if ($project->data['project_status'] == THOR_STATUS_BLOCKED) {
    // The project is blocked -> don't allow team management
    $notification->push(sprintf(_("You can't access that page: the project has been blocked.")), 'horde.warning');
    header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
    exit;
}

$groups = &Group::singleton();

$users_sortby = Util::getFormData('users_sortby', $prefs->getValue('users_sortby'));
$users_sortdir = Util::getFormData('users_sortdir', $prefs->getValue('users_sortdir'));
$actionID = Util::getFormData('actionID');
$userID = Util::getFormData('userID');
$groupID = Util::getFormData('groupID');
$show_confirmation = false;

if (isset($groupID) ) {
    $group = &$groups->getGroupById($groupID);
} else {
    // Get the top group by default
    $group = &$groups->getGroup($project->_top_group_name);
    $groupID = $group->getId();
}

if ( isset($actionID) && !empty($project) && isset($userID)) {
    $confirm = Util::getFormData('confirm');

    switch ($actionID) {
    case UPGRADE_USER:
        if ($confirm == _("Yes")) {
            // The user has confirmed the action.
            $old_group = $project->_default_groups[USERS_DEVS];
            $new_group = $project->_default_groups[USERS_ADMINS];
            if ($project->changeUserGroup($userID, $old_group, $new_group)) {
                // All went ok
                $notification->push(sprintf(_("'%s' is now an administrator."), $userID), 'horde.success');
            } else {
                // There was a problem
                $notification->push(sprintf(_("Could not set '%s' as an administrator."), $userID), 'horde.error');
            }
        } elseif (!isset($confirm)) {
            // The user has not confirmed the action yet.
            $confirm_text = sprintf(_("Are you sure you want to give '%s' administrator privileges?"), $userID);
            $show_confirmation = true;
        }
        break;

    case DOWNGRADE_USER:
        if ($confirm == _("Yes")) {
            // The user has confirmed the action.
            $old_group = $project->_default_groups[USERS_ADMINS];
            $new_group = $project->_default_groups[USERS_DEVS];
            if ($project->changeUserGroup($userID, $old_group, $new_group)) {
                // All went ok
                $notification->push(sprintf(_("'%s' is now a developer."), $userID), 'horde.success');
            } else {
                // There was a problem
                $notification->push(sprintf(_("Could not set '%s' as a developer."), $userID), 'horde.error');
            }
        } elseif (!isset($confirm)) {
            // The user has not confirmed the action yet.
            $confirm_text = sprintf(_("Are you sure you want to remove '%s' administrator privileges?"), $userID);
            $show_confirmation = true;
        }
        break;

    case DISCHARGE_USER:
        if ($confirm == _("Yes")) {
            // The user has confirmed the action
            $old_group = $group->getName();
            $new_group = $project->_default_groups[USERS_DISCHARGED];
            if ($project->changeUserGroup($userID, $old_group, $new_group)) {
                // All went ok
                $notification->push(sprintf(_("'%s' has been discharged."), $userID), 'horde.success');
            } else {
                $notification->push(sprintf(_("Could not discharge '%s'."), $userID), 'horde.error');
            }
        } elseif (!isset($confirm)) {
            // The user has not confirmed the action yet.
            $confirm_text = sprintf(_("Are you sure you want to discharge '%s'?"), $userID);
            $show_confirmation = true;
        }
        break;

    case ACCEPT_REQUEST:
        if ($confirm == _("Yes")) {
            // The user has confirmed the action
            if ($project->acceptUserRequest($userID)) {
                $notification->push(sprintf(_("'%s' has been accepted."), $userID), 'horde.success');
            } else {
                $notification->push(sprintf(_("'%s' could not join the team."), $userID), 'horde.error');
            }
        } elseif (!isset($confirm)) {
            // The user has not confirmed the action yet.
            $confirm_text = sprintf(_("Are you sure you want '%s' to join your team?"), $userID);
            $show_confirmation = true;
        }
        break;

    case REFUSE_REQUEST:
        if ($confirm == _("Yes")) {
            // The user has confirmed the action
            if ($project->refuseUserRequest($userID)) {
                $notification->push(sprintf(_("'%s' has been refused."), $userID), 'horde.success');
            } else {
                $notification->push(sprintf(_("Could not refuse '%s'."), $userID), 'horde.error');
            }
        } elseif (!isset($confirm)) {
            // The user has not confirmed the action yet.
            $confirm_text = sprintf(_("Are you sure you don't want '%s' to join your team?"), $userID);
            $show_confirmation = true;
        }
        break;

    case REMOVE_USER:
        if ($confirm == _("Yes")) {
            // The user has confirmed
            $groupName = $group->getName();
            if ($groups->userIsInGroup($userID, $groupName, false)) {
                $group->removeUser($userID);
                $notification->push(sprintf(_("'%s' has been removed from '%s'."), $userID, $groupName), 'horde.success');
            } else {
                $notification->push(sprintf(_("'%s' could not be removed from '%s'."), $userID, $groupName), 'horde.error');
            }
        } elseif (!isset($confirm)) {
            // The user has not confirmed the action yet.
            $confirm_text = sprintf(_("Are you sure you want to remove '%s' from '%s'?"), $userID, $group->getName() );
            $show_confirmation = true;
        }
        break;
    }
}

/* Set the page title */
$title = htmlspecialchars($project->getShortName()) . ' :: ' . _("Team Management");
require THOR_TEMPLATES . '/common-header.inc';
require THOR_TEMPLATES . '/menu.inc';

if ($show_confirmation) {
    // Show the correct confirmation form.
    require THOR_TEMPLATES . '/team/confirmation.inc';
}

$project->showInformation();
$project->showProjectGroupsTree($groupID);
$project->showUsers($group, $users_sortby, $users_sortdir, true,  true, true);